@@ -34,7 +34,11 @@ import tornado.options
 # Global resource handler variable
 resource_manager = ResourceManager()
 
-assets_path = Path(__file__).parent.parent / 'webapp' / 'public' / 'assets'
+repo_root = Path(__file__).absolute().parent
+if __name__ == '__main__':
+    # If we're running this file directly, then we have to go up one more
+    repo_root = repo_root.parent
+assets_path = repo_root / 'webapp' / 'public' / 'assets'
 data_path = Path.cwd() / 'local_hs_resources'
 
 # If we're running this file directly with Python, we'll be firing up a full
